@@ -43,7 +43,7 @@ public:
                           const QString &type, const QString &location);
     KImportedBookmarkMenu(KBookmarkManager *mgr,
                           KBookmarkOwner *owner, QMenu *parentMenu);
-    ~KImportedBookmarkMenu();
+    ~KImportedBookmarkMenu() override;
     void clear() override;
     void refill() override;
 protected Q_SLOTS:
@@ -88,7 +88,7 @@ public:
           KBookmarkActionInterface(KBookmark())
     {
     }
-    ~KImportedBookmarkActionMenu()
+    ~KImportedBookmarkActionMenu() override
     {}
 };
 
